@@ -113,8 +113,8 @@ supermod.mixedFactoidType.subclass = mixedFactoidTypeSub
 
 
 class BaseTypeSub(supermod.BaseType):
-    def __init__(self, BaseProperty1=None, BaseProperty2=None, valueOf_=None):
-        super(BaseTypeSub, self).__init__(BaseProperty1, BaseProperty2, valueOf_, )
+    def __init__(self, BaseProperty1=None, BaseProperty2=None, valueOf_=None, extensiontype_=None):
+        super(BaseTypeSub, self).__init__(BaseProperty1, BaseProperty2, valueOf_, extensiontype_, )
 supermod.BaseType.subclass = BaseTypeSub
 # end class BaseTypeSub
 
